@@ -1,11 +1,12 @@
 #!/usr/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdal_retile as a convenience to use as a script
 from osgeo_utils.gdal_retile import *  # noqa
 from osgeo_utils.gdal_retile import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdal_retile')
+deprecation_warn("gdal_retile")
 sys.exit(main(sys.argv))
